import{_ as m,c as h,a as o,b,t as i,d as l,e as n,w as r,E as c,n as g,f as d,u as k,I as v,o as f}from"./index-CQQR053H.js";const C={name:"AboutPage",data(){const{t:s}=k();return{devClickCount:0,showDevelopMode:localStorage.getItem("showDevelopMode")==="true"&&!v,demoErrorKey:"",t:s}},mounted(){},beforeUnmount(){this.demoErrorKey=""},methods:{generateDemoErrorKey(){const s=Math.floor(Math.random()*7)+1;this.demoErrorKey=`setting.develop_mode.message.error.demo.${s}`},handleDevClick(){if(this.showDevelopMode){d.info(this.t("setting.develop_mode.message.info.already"));return}this.devClickCount++;const s=7-this.devClickCount;s>0&&s<6&&d.info(this.t("setting.develop_mode.message.info.remain",{remain:s})),this.devClickCount>=7&&(localStorage.setItem("showDevelopMode","true"),this.showDevelopMode=!0,d.success(this.t("setting.develop_mode.message.success")),this.devClickCount=0)},goToRepo(){window.open("https://github.com/Teahouse-Studios/akari-bot","_blank")},goToWebUIRepo(){window.open("https://github.com/Teahouse-Studios/akari-bot-webui","_blank")},goToI18N(){window.open("https://crowdin.com/project/akari-bot","_blank")},goToSponsor(){window.open("https://afdian.com/a/teahouse","_blank")}}},w={class:"container"},_={class:"quote"},T={class:"repo-buttons"},S={class:"github-link"},D=["title"],y={class:"github-link"},I=["title"],M={class:"other-links"},E={class:"footer-text"};function B(s,t,R,A,u,e){const a=c;return f(),h("div",w,[t[7]||(t[7]=o("img",{width:"300",src:b,alt:"Akaribot"},null,-1)),t[8]||(t[8]=o("h1",{class:"title"},"小可 · AkariBot",-1)),o("span",_,i(s.$t("about.slogan")),1),t[9]||(t[9]=o("span",{class:"text"},[l(" By "),o("a",{href:"https://github.com/OasisAkari"},"OasisAkari"),l(" via "),o("a",{href:"https://teahouse.team"},"Teahouse Studios")],-1)),o("div",T,[o("div",S,[n(a,{class:"repo-button",onClick:e.goToRepo},{default:r(()=>[t[1]||(t[1]=o("i",{class:"mdi mdi-github"},null,-1)),o("span",null,i(s.$t("about.button.repo.main")),1)]),_:1},8,["onClick"]),o("img",{src:"https://img.shields.io/github/stars/Teahouse-Studios/akari-bot?style=social",alt:"Repo Stars",title:s.$t("about.star.tooltip")},null,8,D)]),o("div",y,[n(a,{class:"repo-button",onClick:e.goToWebUIRepo},{default:r(()=>[t[2]||(t[2]=o("i",{class:"mdi mdi-github"},null,-1)),o("span",null,i(s.$t("about.button.repo.webui")),1)]),_:1},8,["onClick"]),o("img",{src:"https://img.shields.io/github/stars/Teahouse-Studios/akari-bot-webui?style=social",alt:"Repo Stars",title:s.$t("about.star.tooltip")},null,8,I)])]),o("div",M,[n(a,{class:"locale-button",onClick:e.goToI18N},{default:r(()=>[t[3]||(t[3]=o("i",{class:"mdi mdi-translate"},null,-1)),o("span",null,i(s.$t("about.button.locale")),1)]),_:1},8,["onClick"]),n(a,{class:"sponsor-button",onClick:e.goToSponsor},{default:r(()=>[t[4]||(t[4]=o("i",{class:"mdi mdi-heart-outline"},null,-1)),o("span",null,i(s.$t("about.button.sponsor")),1)]),_:1},8,["onClick"])]),o("span",E,[t[5]||(t[5]=l(" Made with love❤️ and ",-1)),o("span",{class:g(["python-text",{disabled:!u.showDevelopMode}]),onClick:t[0]||(t[0]=(...p)=>e.handleDevClick&&e.handleDevClick(...p))}," Python🐍 ",2),t[6]||(t[6]=l(". ",-1))])])}const $=m(C,[["render",B],["__scopeId","data-v-fb79b696"]]);export{$ as default};
