import{bC as v,bH as y,cD as O,cE as p,cF as x,bD as b,cG as m,cH as w,cI as i}from"./index-CQQR053H.js";var a=Object.create,P=(function(){function e(){}return function(r){if(!v(r))return{};if(a)return a(r);e.prototype=r;var n=new e;return e.prototype=void 0,n}})();function B(e,r){var n=-1,t=e.length;for(r||(r=Array(t));++n<t;)r[n]=e[n];return r}function D(e,r,n,t){var g=!n;n||(n={});for(var u=-1,h=r.length;++u<h;){var s=r[u],o=void 0;o===void 0&&(o=e[s]),g?y(n,s,o):O(n,s,o)}return n}function A(e){var r=[];if(e!=null)for(var n in Object(e))r.push(n);return r}var C=Object.prototype,I=C.hasOwnProperty;function E(e){if(!v(e))return A(e);var r=p(e),n=[];for(var t in e)t=="constructor"&&(r||!I.call(e,t))||n.push(t);return n}function H(e){return b(e)?x(e,!0):E(e)}var K=m(Object.getPrototypeOf,Object),d=typeof exports=="object"&&exports&&!exports.nodeType&&exports,f=d&&typeof module=="object"&&module&&!module.nodeType&&module,L=f&&f.exports===d,c=L?w.Buffer:void 0,l=c?c.allocUnsafe:void 0;function z(e,r){if(r)return e.slice();var n=e.length,t=l?l(n):new e.constructor(n);return e.copy(t),t}function T(e){var r=new e.constructor(e.byteLength);return new i(r).set(new i(e)),r}function F(e,r){var n=r?T(e.buffer):e.buffer;return new e.constructor(n,e.byteOffset,e.length)}function G(e){return typeof e.constructor=="function"&&!p(e)?P(K(e)):{}}export{B as a,z as b,D as c,F as d,T as e,K as g,G as i,H as k};
