import{bG as C,cu as F,cv as _,cw as N,cx as v,cy as m,bI as B,cz as j,cA as E,cB as u,bC as K,bJ as R,bO as J,cC as W,bL as Y,cD as q}from"./index-CQQR053H.js";import{c as T,k as p,g as H,e as x,d as Q,a as V,b as X,i as Z}from"./_initCloneObject-BRKkjwMM.js";function z(e,r){for(var n=-1,o=e==null?0:e.length;++n<o&&r(e[n],n,e)!==!1;);return e}function k(e,r){return e&&T(r,C(r),e)}function ee(e,r){return e&&T(r,p(r),e)}function re(e,r){return T(e,F(e),r)}var te=Object.getOwnPropertySymbols,L=te?function(e){for(var r=[];e;)N(r,F(e)),e=H(e);return r}:_;function ne(e,r){return T(e,L(e),r)}function ae(e){return v(e,p,L)}var oe=Object.prototype,ce=oe.hasOwnProperty;function se(e){var r=e.length,n=new e.constructor(r);return r&&typeof e[0]=="string"&&ce.call(e,"index")&&(n.index=e.index,n.input=e.input),n}function ie(e,r){var n=r?x(e.buffer):e.buffer;return new e.constructor(n,e.byteOffset,e.byteLength)}var be=/\w*$/;function ge(e){var r=new e.constructor(e.source,be.exec(e));return r.lastIndex=e.lastIndex,r}var O=m?m.prototype:void 0,w=O?O.valueOf:void 0;function fe(e){return w?Object(w.call(e)):{}}var ye="[object Boolean]",ue="[object Date]",Te="[object Map]",le="[object Number]",je="[object RegExp]",pe="[object Set]",Ae="[object String]",de="[object Symbol]",$e="[object ArrayBuffer]",Se="[object DataView]",me="[object Float32Array]",Oe="[object Float64Array]",we="[object Int8Array]",Ie="[object Int16Array]",he="[object Int32Array]",Ce="[object Uint8Array]",Fe="[object Uint8ClampedArray]",Be="[object Uint16Array]",Ee="[object Uint32Array]";function xe(e,r,n){var o=e.constructor;switch(r){case $e:return x(e);case ye:case ue:return new o(+e);case Se:return ie(e,n);case me:case Oe:case we:case Ie:case he:case Ce:case Fe:case Be:case Ee:return Q(e,n);case Te:return new o;case le:case Ae:return new o(e);case je:return ge(e);case pe:return new o;case de:return fe(e)}}var Le="[object Map]";function Me(e){return B(e)&&j(e)==Le}var I=u&&u.isMap,Ue=I?E(I):Me,Pe="[object Set]";function De(e){return B(e)&&j(e)==Pe}var h=u&&u.isSet,Ge=h?E(h):De,_e=1,Ne=2,ve=4,M="[object Arguments]",Ke="[object Array]",Re="[object Boolean]",Je="[object Date]",We="[object Error]",U="[object Function]",Ye="[object GeneratorFunction]",qe="[object Map]",He="[object Number]",P="[object Object]",Qe="[object RegExp]",Ve="[object Set]",Xe="[object String]",Ze="[object Symbol]",ze="[object WeakMap]",ke="[object ArrayBuffer]",er="[object DataView]",rr="[object Float32Array]",tr="[object Float64Array]",nr="[object Int8Array]",ar="[object Int16Array]",or="[object Int32Array]",cr="[object Uint8Array]",sr="[object Uint8ClampedArray]",ir="[object Uint16Array]",br="[object Uint32Array]",t={};t[M]=t[Ke]=t[ke]=t[er]=t[Re]=t[Je]=t[rr]=t[tr]=t[nr]=t[ar]=t[or]=t[qe]=t[He]=t[P]=t[Qe]=t[Ve]=t[Xe]=t[Ze]=t[cr]=t[sr]=t[ir]=t[br]=!0;t[We]=t[U]=t[ze]=!1;function l(e,r,n,o,g,c){var a,f=r&_e,y=r&Ne,D=r&ve;if(n&&(a=g?n(e,o,g,c):n(e)),a!==void 0)return a;if(!K(e))return e;var A=Y(e);if(A){if(a=se(e),!f)return V(e,a)}else{var b=j(e),d=b==U||b==Ye;if(R(e))return X(e,f);if(b==P||b==M||d&&!g){if(a=y||d?{}:Z(e),!f)return y?ne(e,ee(a,e)):re(e,k(a,e))}else{if(!t[b])return g?e:{};a=xe(e,b,f)}}c||(c=new J);var $=c.get(e);if($)return $;c.set(e,a),Ge(e)?e.forEach(function(s){a.add(l(s,r,n,s,e,c))}):Ue(e)&&e.forEach(function(s,i){a.set(i,l(s,r,n,i,e,c))});var G=D?y?ae:W:y?p:C,S=A?void 0:G(e);return z(S||e,function(s,i){S&&(i=s,s=e[i]),q(a,i,l(s,r,n,i,e,c))}),a}export{l as b,ae as g};
